@@ -1,18 +1,8 @@
-//    Copyright (C) 2010 Dirk Vanden Boer <dirk.vdb@gmail.com>
-//
-//    This program is free software; you can redistribute it and/or modify
-//    it under the terms of the GNU General Public License as published by
-//    the Free Software Foundation; either version 2 of the License, or
-//    (at your option) any later version.
-//
-//    This program is distributed in the hope that it will be useful,
-//    but WITHOUT ANY WARRANTY; without even the implied warranty of
-//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-//    GNU General Public License for more details.
-//
-//    You should have received a copy of the GNU General Public License
-//    along with this program; if not, write to the Free Software
-//    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+/*
+    SPDX-FileCopyrightText: 2010 Dirk Vanden Boer <dirk.vdb@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "videothumbnailer.h"
 
@@ -20,12 +10,13 @@
 #include "filmstripfilter.h"
 #include "imagewriter.h"
 
+#include <QtGlobal>
+#include <QTime>
+
 #include <iostream>
 #include <cfloat>
 #include <cmath>
-#include <qglobal.h>
 #include <sys/stat.h>
-#include <QTime>
 
 
 using namespace std;
@@ -96,7 +87,7 @@ int timeToSeconds(const QString& time)
 
 void VideoThumbnailer::generateThumbnail(const QString& videoFile, ImageWriter& imageWriter, QImage &image)
 {
-    MovieDecoder movieDecoder(videoFile, NULL);
+    MovieDecoder movieDecoder(videoFile, nullptr);
     if (movieDecoder.getInitialized()) {
         if (!movieDecoder.decodeVideoFrame()) { //before seeking, a frame has to be decoded
             return;
@@ -116,7 +107,7 @@ void VideoThumbnailer::generateThumbnail(const QString& videoFile, ImageWriter&
         }
         
         applyFilters(videoFrame);
-        imageWriter.writeFrame(videoFrame, image);
+        imageWriter.writeFrame(videoFrame, image, movieDecoder.transformations());
     }
 }
 
